#!/usr/bin/env python
# -*- coding: utf-8  -*-
################################################################################
#
#  Rattail -- Retail Software Framework
#  Copyright © 2010-2012 Lance Edgar
#
#  This file is part of Rattail.
#
#  Rattail is free software: you can redistribute it and/or modify it under the
#  terms of the GNU Affero General Public License as published by the Free
#  Software Foundation, either version 3 of the License, or (at your option)
#  any later version.
#
#  Rattail is distributed in the hope that it will be useful, but WITHOUT ANY
#  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
#  FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for
#  more details.
#
#  You should have received a copy of the GNU Affero General Public License
#  along with Rattail.  If not, see <http://www.gnu.org/licenses/>.
#
################################################################################

"""
``rattail.pyramid.views.vendors`` -- Vendor Views
"""

from edbob.pyramid.views import SearchableAlchemyGridView, AutocompleteView
from edbob.pyramid.views.crud import Crud

import rattail


class VendorsGrid(SearchableAlchemyGridView):

    mapped_class = rattail.Vendor
    route_name = 'vendors'
    route_url = '/vendors'
    renderer = '/vendors/index.mako'
    permission = 'vendors.list'
    sort = 'name'

    def filter_map(self):
        return self.make_filter_map(ilike=['name'])

    def filter_config(self):
        return self.make_filter_config(
            include_filter_name=True,
            filter_type_name='lk',
            filter_label_id="ID")

    def sort_map(self):
        return self.make_sort_map('id', 'name')

    def grid(self):
        g = self.make_grid()
        g.configure(
            include=[
                g.id.label("ID"),
                g.name,
                g.phone,
                g.contact,
                ],
            readonly=True)
        return g


class VendorCrud(Crud):

    mapped_class = rattail.Vendor
    home_route = 'vendors.list'

    def fieldset(self, obj):
        fs = self.make_fieldset(obj)
        fs.configure(
            include=[
                fs.id,
                fs.name,
                ])
        return fs


class VendorAutocomplete(AutocompleteView):

    mapped_class = rattail.Vendor
    fieldname = 'name'


def includeme(config):
    VendorsGrid.add_route(config)
    VendorCrud.add_routes(config)
    VendorAutocomplete.add_route(config)
